@@ -43,6 +43,7 @@ class MaintenanceNotification(BaseModel):
     subject: str
     provider_type: str
     raw_payload: bytes
+    date: str
 
 
 class Source(BaseModel):
@@ -261,11 +262,15 @@ class EmailSource(Source):  # pylint: disable=abstract-method
         self, job_logger: Job, email_message: email.message.EmailMessage
     ) -> Optional[MaintenanceNotification]:
         """Process an EmailMessage to create the MaintenaceNotification."""
-        email_source = self.extract_email_source(email_message[self.source_header])
+        email_source = None
+        if email_message[self.source_header]:
+            email_source = self.extract_email_source(email_message[self.source_header])
+
         if not email_source:
-            job_logger.log_warning(
+            job_logger.log_failure(
+                email_message,
                 message="Not possible to determine the email sender from "
-                f'"{self.source_header}: {email_message[self.source_header]}"'
+                f'"{self.source_header}: {email_message[self.source_header]}"',
             )
             return None
 
@@ -280,6 +285,7 @@ class EmailSource(Source):  # pylint: disable=abstract-method
             subject=email_message["Subject"],
             provider_type=provider_type,
             raw_payload=email_message.as_bytes(),
+            date=email_message["Date"],
         )
 
 
